@@ -1,2 +1,2 @@
 from .finders import find_objects, is_tool, tools_requirements
-from .generic import extension, shell, whoami
+from .generic import extension
