@@ -1,35 +1,51 @@
-import os
 import platform
+from concurrent.futures import ThreadPoolExecutor
 from contextlib import suppress
 from datetime import datetime
 from functools import wraps
 from typing import Any
 
 
-def denying_os(os_name) -> Any:
+def denying_os(*os_name, is_func=False) -> Any:
     """
     Decorator to ban an operating system from software through os.name.
 
     .. code-block:: python
 
-        from snakypy.helpers.utils.decorators import denying_os
+        from snakypy.helpers.decorators import denying_os
 
-        @denying_os("nt")
-        def foo():
-            print("Hi")
+        @denying_os("Windows", "macOS", is_func=True)
+        def systemd_analyze(opt):
+            from subprocess import call
+            call(["systemd-analyze", opt)
+        systemd_analyze("blame")
 
     Args:
+        is_func: (bool): If it is False, it returns a message stating that the operating
+                         system is incompatible, if it is True, it returns that a function/method
+                         is incompatible with the OS.
         os_name (str): You must receive the os.name of the operating system to be banned.
-                       Windows = nt
-                       Linux/Mac OS = posix
+                       Windows = Windows
+                       macOS = Darwin
+                       Linux = Linux
     """
 
     def decorator(func: Any) -> Any:
         @wraps(func)
         def wrapper(*args, **kwargs):
-            if os.name == os_name:
-                msg = f"This software is not compatible with this ({os_name}) operating system."
-                raise Exception(msg)
+            types = ("Windows", "Linux", "macOS")
+            for item in os_name:
+                if item not in types:
+                    raise TypeError(
+                        f'Type error in decorator "{denying_os.__name__}". Options: {", ".join(types)}'
+                    )
+                os_name_ = "Darwin" if item == "macOS" else item
+                if platform.system() == os_name_:
+                    msg = f"This software is not compatible with the operating system: {item}."
+                    if is_func:
+                        msg = f'The function "{func.__name__}" is not supported by the operating system: {item}'
+                    raise Exception(msg)
+
             return func(*args, **kwargs)
 
         return wrapper
@@ -124,4 +140,36 @@ def silent_errors(func: Any) -> Any:
     return wrapper
 
 
-__all__ = ["only_linux", "denying_os", "runtime", "silent_errors"]
+def asynchronous():
+    """
+        Decorator for asynchronous execution application inside a function or method
+
+        .. code-block:: python
+
+            from snakypy.helpers.utils.decorators import asynchronous
+
+            @asynchronous()
+            def foo():
+                func1()
+                func2()
+                func3()
+
+            foo()
+
+
+    Returns:
+
+    """
+
+    def decorator(func):
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            executor = ThreadPoolExecutor()
+            executor.submit(func, *args, **kwargs)
+
+        return wrapper
+
+    return decorator
+
+
+__all__ = ["only_linux", "denying_os", "runtime", "silent_errors", "asynchronous"]
